@@ -26,6 +26,7 @@ use anyhow::Result;
 use futures::AsyncReadExt;
 use futures::AsyncSeekExt;
 use futures::StreamExt;
+use opendal::error::Kind;
 use opendal::ObjectMode;
 use opendal::Operator;
 use rand::prelude::*;
@@ -50,6 +51,7 @@ impl BehaviorTest {
     pub async fn run(&mut self) -> Result<()> {
         self.test_normal().await?;
         self.test_stat_root().await?;
+        self.test_stat_non_exist().await?;
 
         Ok(())
     }
@@ -138,6 +140,19 @@ impl BehaviorTest {
         Ok(())
     }
 
+    /// Stat non exist object should return ObjectNotExist.
+    async fn test_stat_non_exist(&mut self) -> Result<()> {
+        let meta = self
+            .op
+            .object(&uuid::Uuid::new_v4().to_string())
+            .metadata()
+            .await;
+        assert!(meta.is_err());
+        let err = meta.unwrap_err();
+        assert_eq!(err.kind(), Kind::ObjectNotExist);
+        Ok(())
+    }
+
     fn gen_bytes(&mut self) -> (Vec<u8>, usize) {
         let size = self.rng.gen_range(1..4 * 1024 * 1024);
         let mut content = vec![0; size as usize];
